@@ -1100,27 +1100,29 @@ class Askdata(SignUp):
 
     def get_dataset_as_df(self, workspace:str, dataset_slug:str):
 
+        datasetId = self.get_dataset_id(dataset_slug, workspace)
+        url = self.base_url + '/smartdataset/data_table/datasets/'+datasetId+'/file'
+        response = self.make_get_request(url)
+        response.raise_for_status()
+        file = open(datasetId+".parquet", 'wb').write(response.content)
+        return pd.read_parquet(datasetId+".parquet")
+
+    def get_dataset_id(self, dataset_slug, workspace):
+        url = self.base_url + '/smartbot/agents/agentslug/' + workspace + '/datasetslug/' + dataset_slug
+        r = self.make_get_request(url)
+        datasetId = r["datasetId"]
+        return datasetId
+
+    def make_get_request(self, url):
         s = requests.Session()
         s.keep_alive = False
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
         s.mount('https://', HTTPAdapter(max_retries=retries))
-
-        url = self.base_url + '/smartbot/agents/agentslug/' + workspace + '/datasetslug/' + dataset_slug
-
         headers = {"Authorization": "Bearer" + " " + self._token}
         response = s.get(url=url, headers=headers)
         response.raise_for_status()
         r = response.json()
-
-        datasetId = r["datasetId"]
-
-        url = self.base_url + '/smartdataset/data_table/datasets/'+datasetId+'/file'
-
-        headers = {"Authorization": "Bearer" + " " + self._token}
-        response = s.get(url=url, headers=headers)
-        response.raise_for_status()
-        file = open(datasetId+".parquet", 'wb').write(response.content)
-        return pd.read_parquet(datasetId+".parquet")
+        return r
 
     def delete_agent(self, agent_slug):
         agent = self.agents_dataframe()[self.agents_dataframe()['slug'] == agent_slug.lower()]
@@ -1182,6 +1184,16 @@ class Askdata(SignUp):
 
         return df.merge(df_query, how, on, left_on, right_on)
 
+
+    def get_fields(self, workspace, dataset_slug):
+        dataset_id = (str)(self.get_dataset_id(dataset_slug, workspace))
+        dataset_type = ""
+        for piece in dataset_id.split("-"):
+            if(piece.isupper()):
+                dataset_type = piece
+        url = "{}/smartbot/dataset/type/{}/id/{}/subset/{}?_page=0&_limit=50".format(self.base_url, dataset_type, dataset_id, dataset_type)
+        return self.make_get_request(url)["payload"]["data"]
+
     def load_dataset(self, workspace_slug, dataset_slug, logs=True):
         all_fields = list(self.get_columns(workspace=workspace_slug, dataset=dataset_slug)["code"])
         limit = 1000
