@@ -642,6 +642,24 @@ class Dataset():
                                             settings_value=value_entity)
                     break
 
+    def edit_dataset_readme(self, readme):
+
+        url = "{}/smartdataset/datasets/{}/metadata".format(self._base_url_askdata, self._dataset_id)
+
+        data = {
+            "featuredColumns": [],
+            "readMe": readme
+        }
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        r = s.put(url=url, headers=self._headers, verify=True, json=data)
+        r.raise_for_status()
+
+
     def get_columns_code(self)->list:
         """
         return the list of column of specific dataset instantiated with slug
