@@ -234,6 +234,8 @@ def nl2query(nl, language="en-US"):
         return smartquery, version
     except Exception as e:
         logging.error(str(e))
+        print("!-!-! Failed SmartQuery object creation. !-!-!")
+        return None, None
 
 
 def complex_field_calculator(smartquery, driver):
@@ -298,3 +300,38 @@ def complex_filter_calculator(smartquery, driver):
         return sql
     except Exception as e:
         logging.error(str(e))
+
+
+def smartner(nl, token, workspace, datasets, language="en-US"):
+    if datasets is None:
+        datasets = []
+
+    headers = {
+        "Content-Type": "application/json"
+    }
+
+    s = requests.Session()
+    s.keep_alive = False
+    retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+    s.mount('https://', HTTPAdapter(max_retries=retries))
+
+    url = url_list['BASE_URL_SMARTNER_DEV'] + "/query"
+
+    data = {
+        "nl": nl,
+        "language": language,
+        "token": token,
+        "workspace": workspace,
+        "datasets": datasets
+    }
+
+    r = s.post(url=url, headers=headers, json=data)
+    r.raise_for_status()
+
+    try:
+        response = r.json()
+        smartqueries_list = response["smartqueries"]
+        return smartqueries_list
+    except Exception as e:
+        logging.error(str(e))
+        return []
