@@ -180,7 +180,14 @@ def run_all_requests(start_date, end_date, token, api_key):
 
         response = requests.request("GET", link, headers=headers)
 
-        dati = response.json()
+        
+        try:
+            dati = response.json()
+            
+        except:
+            print(response)
+            print('page', page)
+            print(start_date, end_date)
 
         total_pages = math.ceil(dati["meta"]["total"]/50)
 
