@@ -121,8 +121,7 @@ def smart_substitution(sentence, language="en"):
         r.raise_for_status()
 
         try:
-            dict_response = r.json()
-            response = dict_response['response']
+            response = r.json()
             return response
         except Exception as e:
             logging.error(str(e))
