@@ -441,6 +441,10 @@ class Query:
             if isinstance(where_condition, Condition):
                 if where_condition.field.column is not None:
                     vars = []
+                    negation = None
+                    if where_condition.negate is not None:
+                        negation = "NOT"
+
                     if where_condition.value is not None:
                         for var in where_condition.value:
                             vars.append(str(var))
@@ -489,25 +493,74 @@ class Query:
                     else:
                         operator = None
 
-                    consistent_vec = consistent_datatypes[where_condition.field.internalDataType.lower()]
-                    if (
-                            where_condition.field.internalDataType.lower() == "numeric" or where_condition.field.internalDataType.lower() == "string") \
-                            and where_condition.field.sourceDataType.lower() not in consistent_vec:
-                        # if internal and original data types are not consistent each other use this pattern
-                        # aggregation column (original data type, to internal data type ) AS Alias
-                        formatted_cond = where_condition.field.column + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ") " + operator + " " + formatted_value
-                    elif where_condition.field.internalDataType.lower() == "date" and where_condition.field.sourceDataType.lower() not in consistent_vec:
-                        # if internal and original data types are not consistent each other use this pattern
-                        # aggregation column (original data type, to internal data type, date_format YYYY-MM-DD ) AS Alias
-                        if where_condition.field.sourceFormat is not None:
-                            formatted_cond = where_condition.field.column + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ", format " + where_condition.field.sourceFormat + ") " + operator + " " + formatted_value
+                    field_with_agg = where_condition.field.column
+                    if where_condition.field.aggregation is not None:
+                        if isinstance(where_condition.field.aggregation, SQLFunction) or isinstance(where_condition.field.aggregation,
+                                                                                         TimeDimensionGranularity):
+                            field_with_agg = where_condition.field.aggregation.name + " ( " + field_with_agg + " )"
                         else:
-                            formatted_cond = where_condition.field.column + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ", format YYYY-MM-DD" + ") " + operator + " " + formatted_value
-                    else:
-                        # else
-                        formatted_cond = where_condition.field.column + " (" + where_condition.field.sourceDataType + ") " + operator + " " + formatted_value
+                            field_with_agg = where_condition.field.aggregation + " ( " + field_with_agg + " )"
 
-                    conditions.append(formatted_cond)
+                    if where_condition.field.internalDataType is not None:
+                        consistent_vec = consistent_datatypes[where_condition.field.internalDataType.lower()]
+                        if (
+                                where_condition.field.internalDataType.lower() == "numeric" or where_condition.field.internalDataType.lower() == "string") \
+                                and where_condition.field.sourceDataType.lower() not in consistent_vec:
+                            # if internal and original data types are not consistent each other use this pattern
+                            # aggregation column (original data type, to internal data type ) AS Alias
+                            formatted_cond = field_with_agg + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ") " + operator + " " + formatted_value
+                        elif where_condition.field.internalDataType.lower() == "date" and where_condition.field.sourceDataType.lower() not in consistent_vec:
+                            # if internal and original data types are not consistent each other use this pattern
+                            # aggregation column (original data type, to internal data type, date_format YYYY-MM-DD ) AS Alias
+                            if where_condition.field.sourceFormat is not None:
+                                formatted_cond = field_with_agg + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ", format " + where_condition.field.sourceFormat + ") " + operator + " " + formatted_value
+                            else:
+                                formatted_cond = field_with_agg + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ", format YYYY-MM-DD" + ") " + operator + " " + formatted_value
+                        else:
+                            # else
+                            formatted_cond = field_with_agg + " (" + where_condition.field.sourceDataType + ") " + operator + " " + formatted_value
+
+                        conditions.append(formatted_cond)
+                    else:
+                        if formatted_value is not None and where_condition.direction is None:
+                            if where_condition.negate is None:
+                                formatted_cond = field_with_agg + " " + operator + " " + str(formatted_value)
+
+                            else:
+                                formatted_cond = field_with_agg + " " + negation + " " + operator + " " + str(formatted_value)
+                        elif formatted_value is None and where_condition.direction is not None:
+                            if isinstance(where_condition.direction, PeriodOperator):
+                                direction = where_condition.direction.name
+                            else:
+                                direction = where_condition.direction
+                            if negation is None:
+                                if where_condition.steps is not None and where_condition.interval is not None:
+                                    formatted_cond = field_with_agg + " " + operator + " " + where_condition.interval + " " + direction + " " + where_condition.steps
+                                elif where_condition.steps is not None and where_condition.interval is None:
+                                    formatted_cond = (
+                                            field_with_agg + " " + operator + " " + direction + " " + where_condition.steps
+                                    )
+                                elif where_condition.steps is None and where_condition.interval is not None:
+                                    formatted_cond = field_with_agg + " " + operator + " " + where_condition.interval + " " + direction
+                                else:
+                                    formatted_cond = field_with_agg + " " + operator + " " + direction
+                            else:
+                                if where_condition.steps is not None and where_condition.interval is not None:
+                                    formatted_cond = field_with_agg + " " + negation + " " + operator + " " + where_condition.interval + " " + direction + " " + where_condition.steps
+                                elif where_condition.steps is not None and where_condition.interval is None:
+                                    formatted_cond = field_with_agg + " " + negation + " " + operator + " " + direction + " " + where_condition.steps
+                                elif where_condition.steps is None and where_condition.interval is not None:
+                                    formatted_cond = field_with_agg + " " + negation + " " + operator + " " + where_condition.interval + " " + direction
+                                else:
+                                    formatted_cond = field_with_agg + " " + negation + " " + operator + " " + direction
+                        elif operator is not None:
+                            if negation is None:
+                                formatted_cond = field_with_agg + " " + operator
+                            else:
+                                formatted_cond = field_with_agg + " " + negation + " " + operator
+                        else:
+                            formatted_cond = field_with_agg
+                        conditions.append(formatted_cond)
                 elif where_condition.field.complexExpression is not None:
                     if where_condition.field.alias is not None:
                         formatted_cond = where_condition.field.complexExpression + " AS " + where_condition.field.alias
@@ -522,7 +575,7 @@ class Query:
                     conditions.append(" OR ".join(other_conds))
         return conditions
 
-    def spell_out(self):
+    def spell_out(self, add_offset=True):
         spell_str = '# {"fields":['
 
         fields = []
@@ -558,8 +611,23 @@ class Query:
                         string = '"' + field.aggregation.name + " " + field.complexExpression + " AS " + field.alias + '"'
                     else:
                         string = '"' + field.complexExpression + " AS " + field.alias + '"'
-            else:
+            elif field.internalDataType is not None:
                 string = self._field_spell_out(field)
+            else:
+                if field.alias is None:
+                    if field.aggregation is not None and isinstance(field.aggregation, str):
+                        string = '"' + field.aggregation + " " + field.column + '"'
+                    elif field.aggregation is not None and isinstance(field.aggregation, SQLFunction):
+                        string = '"' + field.aggregation.name + " " + field.column + '"'
+                    else:
+                        string = '"' + field.column + '"'
+                else:
+                    if field.aggregation is not None and isinstance(field.aggregation, str):
+                        string = '"' + field.aggregation + " " + field.column + " AS " + field.alias + '"'
+                    elif field.aggregation is not None and isinstance(field.aggregation, SQLFunction):
+                        string = '"' + field.aggregation.name + " " + field.column + " AS " + field.alias + '"'
+                    else:
+                        string = '"' + field.column + " AS " + field.alias + '"'
             fields.append(string)
         spell_str += ", ".join(fields) + "]"
 
@@ -592,10 +660,11 @@ class Query:
         if self.limit is not None:
             spell_str += ', "limit": ' + str(self.limit)
 
-        if self.offset is not None:
-            spell_str += ', "offset": ' + str(self.offset)
-        else:
-            spell_str += ', "offset": 0'
+        if add_offset:
+            if self.offset is not None:
+                spell_str += ', "offset": ' + str(self.offset)
+            else:
+                spell_str += ', "offset": 0'
 
         spell_str += "}"
         return spell_str
@@ -607,10 +676,10 @@ class SmartQuery:
     components: Optional[List[Union[ChartComponent, MapComponent, QueryComponent, Component]]] = None
     javascript: Optional[List[str]] = None
 
-    def spell_out(self):
+    def spell_out(self, add_offset=True):
         spell_array = []
         for query in self.queries:
-            spell = query.spell_out()
+            spell = query.spell_out(add_offset)
             spell_array.append(spell)
         return spell_array
 
