@@ -1,4 +1,6 @@
 import requests
+import json
+import pprint
 from askdata.askdata_client import *
 
 ### function for testing login, this function is used inside run_authentication_test and return the response
@@ -229,9 +231,6 @@ def run_test(query = '',
     
     response = run_query(glob_token, agent_id, query)
     
-    #this print is helpful for debugging code00
-    #print(response.json()[0]['attachment']['body'])
-    
     
     ##check all the test for a query
     try:
@@ -303,7 +302,14 @@ def run_test(query = '',
         print('Test Failed')
         
     
+    message_body += "<details><summary><br><b>Response:\n</b></summary>" + '<pre>' + pprint.pformat(response.json()[0]) + '\n</pre></details>'
     
+    #this print is helpful for debugging code
+    print("Response:")
+    print(json.dumps(response.json()[0]['attachment']['body'], 
+          sort_keys = False, indent = 4))
+          
+          
     return message_body
 
 
